[![logo](https://www.hongsnet.net/images/logo.gif)](https://www.hongsnet.net)

# Ansible의 copy,file 모듈 및 jinja2 템플릿을 이용한 MariaDB 설치

> MariaDB 설치를 자동화 할 수 있다.


## 주요 기능

- templates/my.cnf.j2 Jinja2 템플릿을 사용하여, server_id,innodb_buffer_pool_size를 조정한다.
- OS 별 MariaDB 패키지를 취사선택(Facts 변수)하여 설치한다.


## Inventory 설정

```bash
# cat hosts
[ALL_HOSTS]
172.16.0.100 managed_ip=172.16.0.100 des="2020-12-03"

[ALL_HOSTS_OK]
```

대상 호스트는 172.16.0.100이며, 추가는 2020-12-03에 수행한다. 참고적으로 **ALL_HOSTS_OK** 호스트 그룹은 작업이 완료된 호스트의 history를 위한 그룹이다.


## Host Variables 설정

```bash
# cat host_vars/172.16.0.100
ansible_ssh_host: 172.16.0.100
ansible_ssh_port: SSH_포트번호
ansible_ssh_user: 사용자 아이디
ansible_ssh_pass: "사용자 패스워드"
ansible_become: yes
ansible_become_method: su
ansible_become_user: root
ansible_become_pass: "!root_패스워드"
ansible_python_interpreter: python2.7
```

## Playbook 설정

```python
---
- name: Debian(Minimal Install) Basic APT Package Install
  hosts: ALL_HOSTS
  vars: 
   server_id: "XX"
   buffer_pool_size: "65535MB"
   mysql_conf_src: "/etc/mysql_src"
  tasks:
   - name: APT sources.list file copy
     copy:
       src: "{{ item }}"
       dest: /etc/apt/sources.list.d
       owner: 'root'
       group: 'root'
       mode: 0644
       #attr: i
     with_items:
       ['MariaDB']
     when: ansible_os_family == "Debian"

   - name: YUM repo file copy
     copy:
       src: "{{ item }}"
       dest: /etc/yum.repos.d
       owner: 'root'
       group: 'root'
       mode: 0644
       #attr: i
     with_items:
       ['MariaDB.repo']
     when: ansible_os_family == "CentOS"
 
   - name: MariaDB 10.3 Installing (APT)
     apt:
       pkg:
        - mariadb-server=10.3
     when: ansible_os_family == "Debian"
   
   - name: MariaDB 10.3 Installing (YUM)
     yum:
       name: {{ item }}
     with_items:
        - MariaDB
        - MariaDB-server
        - MariaDB-client
     when: ansible_os_family == "CentOS"

   - name: MariaDB Basic Setting
     command: cp -rfp /etc/mysql /etc/mysql_src
     when: mysql_conf_src is not exists

   - name: MariaDB config files copy
     copy:
       src: "{{ item.src }}"
       dest: "{{ item.dest }}"
       owner: 'root'
       group: 'root'
     with_items:
       - { src: mysql_config/debian-start, dest: /etc/mysql/debian-start }
       - { src: mysql_config/debian.cnf, dest: /etc/mysql/debian.cnf }
       - { src: mysql_config/mariadb.cnf, dest: /etc/mysql/conf.d/mariadb.cnf }
       - { src: mysql_config/mysqld_safe_syslog.cnf, dest: /etc/mysql/conf.d/mysqld_safe_syslog.cnf }
       - { src: mysql_config/tokudb.cnf, dest: /etc/mysql/conf.d/tokudb.cnf }
     when: ansible_os_family == "Debian"

   - name: mysql config files permission set
     file:
       path: "{{ item.path }}"
       mode: "{{ item.mode }}"
     with_items:
       - { path: /etc/mysql/debian-start, mode: 755 }
       - { path: /etc/mysql/debian.cnf, mode: 600 }
       - { path: /etc/mysql/conf.d/mariadb.cnf, mode: 644 }
       - { path: /etc/mysql/conf.d/mysqld_safe_syslog.cnf, mode: 644 }
       - { path: /etc/mysql/conf.d/tokudb.cnf, mode: 644 }
     when: ansible_os_family == "Debian"

   - name: my.cnf configuration
     template: src=templates/my.cnf.j2 dest=/etc/mysql/my.cnf mode=0644
     when: ansible_os_family == "Debian"

   - name: my.cnf configuration
     template: src=templates/my.cnf.j2 dest=/etc/my.cnf mode=0644
     when: ansible_os_family == "CentOS"

   - name: mysqld Daemon Restart
     systemd:
        state: restarted
        name: mariadb.service
        enabled: True
```

jinja2 템플릿 내역은 다음과 같다. 참고적으로 핵심적인 내역만은 명시한다.

```bash
# cat templates/my.cnf.j2
...중략
server-id               = {{ server_id }}
...중략
innodb_buffer_pool_size = {{ buffer_pool_size }}
```

`MariaDB 자동설치`에 대한 Playbook 분석

* [ ] MariaDB의 최신버전을 설치하려면, APT의 sources.list 파일에 알맞는 설정을 수행해야 한다.
* [ ] 위의 Playbook은 SLAVE DBMS의 배포로써 server_id,innodb_buffer_pool_size를 변수로 받는다.
* [ ] 큰 틀에서는 기존 설정을 백업하고, 미리 약속된 설정을 배포하는데 유용하다.


## playbook 실행

```bash
# ansible-playbook -i hosts mariadb_install.yml
```
