[![logo](https://www.hongsnet.net/images/logo.gif)](https://www.hongsnet.net)

# Ansible을 이용한 보안취약점 조치

> 사용자 패스워드정책파일(/etc/login.defs)에 대한 설정취약점을 조치한다.


## Inventory 설정

```bash
# cat hosts
[ALL_HOSTS]
172.16.0.100 managed_ip=172.16.0.100 des="2020-12-03"

[ALL_HOSTS_OK]
```

대상 호스트는 172.16.0.100이며, 추가는 2020-12-03에 수행한다. 참고적으로 **ALL_HOSTS_OK** 호스트 그룹은 작업이 완료된 호스트의 history를 위한 그룹이다.


## Host Variables 설정

```bash
# cat host_vars/172.16.0.100
ansible_ssh_host: 172.16.0.100
ansible_ssh_port: SSH_포트번호
ansible_ssh_user: 사용자 아이디
ansible_ssh_pass: "사용자 패스워드"
ansible_become: yes
ansible_become_method: su
ansible_become_user: root
ansible_become_pass: "!root_패스워드"
ansible_python_interpreter: python2.7
```

## Playbook 설정

```python
---
- name: OS Secure Fix
  hosts: ALL_HOSTS
  tasks:
    - name: Modify Password Min Length
      lineinfile: dest=/etc/login.defs regexp="PASS_MIN_LEN" line="PASS_MIN_LEN  8" state=present

    - name: Modify Password Max Days
      lineinfile: dest=/etc/login.defs regexp="^PASS_MAX_DAYS[\s\x20]*[0-9]*" line="PASS_MAX_DAYS  90" state=present
 
    - name: Modify Password Min Days
      lineinfile: dest=/etc/login.defs regexp="^PASS_MIN_DAYS[\s\x20]*[0-9]*" line="PASS_MIN_DAYS  1" state=present
```


`보안취약점 조치`에 대한 Playbook 분석

* [ ] lineinfile 모듈을 사용하여, 정책에 맞게 내역을 수정한다.
  - PASS_MIN_LEN : 패스워드 최소길이
  - PASS_MAX_DAYS : 패스워드 최대사용기간
  - PASS_MIN_DAYS : 패스워드 변경 후 최소로 사용해야하는 기간


## playbook 실행

```bash
# ansible-playbook -i hosts login_defs.yml
```
